pyhsm.version.YHSM_Version

Package pyhsm :: Module version :: Class YHSM_Version |
[frames] | no frames]

# Class YHSM_Version

Keeps the YubiHSM's version number and can tell what capabilities it has.

Instance Methods
__init__(self, sysinfo) |
have_key_storage_unlock(self) YSM_KEY_STORAGE_UNLOCK was removed in 1.0. |
have_key_store_decrypt(self) YSM_KEY_STORE_DECRYPT was introduced in 1.0, replacing YSM_KEY_STORAGE_UNLOCK. |
have_unlock(self) YSM_HSM_UNLOCK, featuring YubiKey OTP unlocking of operations, was introduced in 1.0. |
have_keycommit(self) YubiHSM have the 'keycommit' command in configuration mode. |
have_keydisable(self) YubiHSM have the 'keydis'(able) command in configuration mode. |
have_YSM_BUFFER_LOAD(self) This is a key handle permission flag that was introduced in 0.9.9. |
have_YSM_DB_YUBIKEY_AEAD_STORE2(self) The 2nd generation store command (with public id != nonce) was introduced in 1.0.4. |

Instance Variables
YHSM_Cmd_System_Info | sysinfo Sysinfo when YubiHSM was initialized.

Method Details

### __init__(self, sysinfo) (Constructor) |
Parameters: `sysinfo` (YHSM_Cmd_System_Info) - YubiHSM sysinfo.

### have_key_storage_unlock(self) |
YSM_KEY_STORAGE_UNLOCK was removed in 1.0. The basic concept of a passphrase to unlock the YubiHSM is now provided with the more secure YSM_KEY_STORE_DECRYPT.

### have_keycommit(self) |
YubiHSM have the 'keycommit' command in configuration mode. 'keycommit' was introduced in 1.0.

### have_keydisable(self) |
YubiHSM have the 'keydis'(able) command in configuration mode. 'keydis' was introduced in 1.0.